FlexibleWrap constructor

const FlexibleWrap({
  1. Key? key,
  2. required List<Widget> children,
  3. TextDirection? textDirection,
  4. double spacing = 0.0,
  5. double runSpacing = 0.0,
  6. bool isOneRowExpanded = false,
})

Creates a FlexibleWrap widget.

The isOneRowExpanded argument determines whether a single row of children can expand to fill the available space. The other parameters control the layout and alignment properties of the wrap.

Implementation

const FlexibleWrap(
    {super.key,
    required super.children,
    this.textDirection,
    this.spacing = 0.0,
    this.runSpacing = 0.0,
    this.isOneRowExpanded = false});